@@ -3,7 +3,7 @@ import torch
 import torch as th
 import torch.nn as nn
 
-from controlnet.ldm.modules.diffusionmodules.util import (
+from controlnet_k.ldm.modules.diffusionmodules.util import (
     conv_nd,
     linear,
     zero_module,
@@ -12,17 +12,17 @@ from controlnet.ldm.modules.diffusionmodules.util import (
 
 from einops import rearrange, repeat
 from torchvision.utils import make_grid
-from controlnet.ldm.modules.attention import SpatialTransformer
-from controlnet.ldm.modules.diffusionmodules.openaimodel import (
+from controlnet_k.ldm.modules.attention import SpatialTransformer
+from controlnet_k.ldm.modules.diffusionmodules.openaimodel import (
     UNetModel,
     TimestepEmbedSequential,
     ResBlock,
     Downsample,
     AttentionBlock,
 )
-from controlnet.ldm.models.diffusion.ddpm import LatentDiffusion
-from controlnet.ldm.util import log_txt_as_img, exists, instantiate_from_config
-from controlnet.ldm.models.diffusion.ddim import DDIMSampler
+from controlnet_k.ldm.models.diffusion.ddpm import LatentDiffusion
+from controlnet_k.ldm.util import log_txt_as_img, exists, instantiate_from_config
+from controlnet_k.ldm.models.diffusion.ddim import DDIMSampler
 
 
 class ControlledUnetModel(UNetModel):
