@@ -35,7 +35,7 @@ from controlnet_k.ldm.modules.distributions.distributions import (
     normal_kl,
     DiagonalGaussianDistribution,
 )
-from controlnet.ldm.models.autoencoder import IdentityFirstStage, AutoencoderKL
+from controlnet_.ldm.models.autoencoder import IdentityFirstStage, AutoencoderKL
 from controlnet_k.ldm.modules.diffusionmodules.util import (
     make_beta_schedule,
     extract_into_tensor,
